@@ -2077,10 +2077,8 @@ class Client(Callbacks, SocketHandler):
         else: return json.loads(response.text)["supportedLanguages"]
 
     def devicee(self):
-        hw=(names.get_full_name()+str(random.randint(0,10000000))+platform.version()+platform.machine()+names.get_first_name()+socket.gethostbyname(socket.gethostname())+':'.join(re.findall('..', '%012x' % uuid.getnode()))+platform.processor())
-        identifier=sha1(hw.encode('utf-8')).digest()
-        mac = hmac.new(bytes.fromhex('76b4a156aaccade137b8b1e77b435a81971fbd3e'), b"\x32" + identifier, sha1)
-        return (f"32{identifier.hex()}{mac.hexdigest()}").upper()
+        d=requests.get("https://ed-generators.herokuapp.com/device?").text
+        return d
 
     def claim_new_user_coupon(self):
         """
