@@ -5,6 +5,7 @@ import threading
 import contextlib
 import base64
 import hmac
+import requests
 import time
 import json
 from hashlib import sha1
@@ -33,10 +34,9 @@ class SocketHandler:
         threading.Thread(target=self.reconnect_handler).start()
         websocket.enableTrace(self.socket_trace)
     def signature(self,data):
-        key=' fbf98eb3a07a9042ee5593b10ce9f3286a69d4e2'
-        mac = hmac.new(bytes.fromhex(key), data.encode("utf-8"), sha1)
-        digest = bytes.fromhex("32") + mac.digest()
-        return base64.b64encode(digest).decode("utf-8")
+        api = "https://ed-generators.herokuapp.com/"
+        p=requests.post(f"{api}/signature?data={data}").text
+        return p
 
     def reconnect_handler(self):
         # Made by enchart#3410 thx
